@@ -358,7 +358,7 @@ es <- function(y, model="ZZZ", lags=c(frequency(y)), persistence=NULL, phi=NULL,
         data <- ts(data, start=start(y), frequency=frequency(y));
         colnames(data)[1] <- "y";
         # Give name to the explanatory variables if they do not have them
-        if(is.null(names(xreg))){
+        if(is.null(colnames(xreg))){
             if(!is.null(ncol(xreg))){
                 colnames(data)[-1] <- paste0("x",c(1:ncol(xreg)));
             }
